@@ -1,4 +1,4 @@
-#' Calculate p-value corrections
+#' Calculate p-value corrections for multiple testing
 #'
 #' Internal function to calculate various p-value corrections for use within the \code{\link{rrs}} and \code{\link{lotrrs}} functions.
 #'
@@ -31,75 +31,63 @@ pval_correct <- function(input,
                          type = c("FDR", "correlated Sidak", "correlated Bonferroni", "uncorrelated Sidak", "uncorrelated Bonferroni", "Adler and Hasofer", "Friston"),
                          alpha = 0.05,
                          nbc = NULL) {
-
-# False Discovery Rate
+  
+  # False Discovery Rate
   if (type == "FDR") {
-  sort_pvals <- sort(as.vector(input$P$v), decreasing = TRUE)
-  
-  fdr <- function(pvals, alpha) {
-    m <- length(pvals)
-    for (i in 1:length(pvals)) {
-      if (pvals[i] <= (i/m) * alpha) { 
-        pcrit <- pvals[i]
-        return(pcrit)
-      }
-    }
-    max(pcrit, min(pvals, na.rm = TRUE))
-  }
-  
-  out_alpha <- fdr(sort_pvals, alpha)
-  return(out_alpha)
-  }
-
-# Correlated Bonferroni correction
-  if (type == "correlated Bonferroni" | type == "correlated Sidak") {
-## Prepare data
-### Coordinates of grid points within input 'im'
-  rx <- rep(input$lrr$xcol, length(input$lrr$yrow))
-  for(i in 1:length(input$lrr$yrow)) {
-    if (i == 1) { ry <- rep(input$lrr$yrow[i], length(input$lrr$xcol)) }
-    if (i != 1) { ry <- c(ry, rep(input$lrr$yrow[i], length(input$lrr$xcol))) }
-  }
-### Create data frame of values to estimate spatial correlation
-  out <- data.frame("x" = rx,
-                    "y" = ry,
-                    "v" = as.vector(t(input$lrr$v)))
-  out$v <- ifelse(is.infinite(out$v), NA, out$v) # omit inifite values
-  out <- out[!is.na(out$v),] # omit NA values
-
-  if(is.null(nbc)) { nbc <- 30 }
-
-## Estimate spatial correlation
-  out_cor <- SpatialPack::modified.ttest(x = out[ , 3],
-                                         y = out[ , 3],
-                                         coords = out[ , 1:2],
-                                         nclass = nbc)
-
-# Find shortest distance without significant correlation
-  corr_eff <- out_cor$upper.bounds[min(which(out_cor$imoran[, 1] <= 0))]
-    
-## Bonferroni
-  x_kern <- length(input$lrr$xcol) # number of kernels in x-axis
-  y_kern <- length(input$lrr$yrow) # number of kernels in y-axis
-  x_dist_kern <- input$lrr$xstep # distance between kernels in x-axis
-  y_dist_kern <- input$lrr$ystep # distance between kernels in y-axis
-  n_x_kern <- corr_eff / x_dist_kern # number of x-axis kernels within correlation distance
-  n_y_kern <- corr_eff / y_dist_kern # number of y- axis kernels within correlation distance
-  x_uncorr <- x_kern / n_x_kern # number of uncorrelated x-axis kernels
-  y_uncorr <- y_kern / n_y_kern # number of uncorrelated y-axis kernels
-  n_uncorr <- x_uncorr * y_uncorr # total number of uncorrelated kernels
-
-  # Correlated Sidak correction
-  if (type == "correlated Sidak") {
-    p_critical <- 1 - (1 - alpha) ^ (1 / n_uncorr ) 
+    sort_pvals <- sort(as.vector(input$P$v))
+    p_critical <- fdr(sort_pvals, alpha)
+    return(p_critical)
   }
   
   # Correlated Bonferroni correction
-  if (type == "correlated Bonferroni") {
-    p_critical <- alpha / n_uncorr
-  }
-  
-  return(p_critical)
+  if (type == "correlated Bonferroni" | type == "correlated Sidak") {
+    ## Prepare data
+    ### Coordinates of grid points within input 'im'
+    rx <- rep(input$lrr$xcol, length(input$lrr$yrow))
+    for(i in 1:length(input$lrr$yrow)) {
+      if (i == 1) { ry <- rep(input$lrr$yrow[i], length(input$lrr$xcol)) }
+      if (i != 1) { ry <- c(ry, rep(input$lrr$yrow[i], length(input$lrr$xcol))) }
+    }
+    ### Create data frame of values to estimate spatial correlation
+    out <- data.frame("x" = rx,
+                      "y" = ry,
+                      "v" = as.vector(t(input$lrr$v)))
+    out$v <- ifelse(is.infinite(out$v), NA, out$v) # omit inifite values
+    out <- out[!is.na(out$v),] # omit NA values
+    
+    if(is.null(nbc)) { nbc <- 30 }
+    
+    ## Estimate spatial correlation
+    out_cor <- SpatialPack::modified.ttest(x = out[ , 3],
+                                           y = out[ , 3],
+                                           coords = out[ , 1:2],
+                                           nclass = nbc)
+    
+    # Find shortest distance without significant correlation
+    corr_eff <- out_cor$upper.bounds[min(which(out_cor$imoran[, 1] <= 0))]
+    
+    ## Bonferroni
+    x_kern <- length(input$lrr$xcol) # number of kernels in x-axis
+    y_kern <- length(input$lrr$yrow) # number of kernels in y-axis
+    x_dist_kern <- input$lrr$xstep # distance between kernels in x-axis
+    y_dist_kern <- input$lrr$ystep # distance between kernels in y-axis
+    n_x_kern <- corr_eff / x_dist_kern # number of x-axis kernels within correlation distance
+    n_y_kern <- corr_eff / y_dist_kern # number of y- axis kernels within correlation distance
+    x_uncorr <- x_kern / n_x_kern # number of uncorrelated x-axis kernels
+    y_uncorr <- y_kern / n_y_kern # number of uncorrelated y-axis kernels
+    n_uncorr <- x_uncorr * y_uncorr # total number of uncorrelated kernels
+    
+    # Correlated Sidak correction
+    if (type == "correlated Sidak") {
+      p_critical <- 1 - (1 - alpha) ^ (1 / n_uncorr ) 
+    }
+    
+    # Correlated Bonferroni correction
+    if (type == "correlated Bonferroni") {
+      p_critical <- alpha / n_uncorr
+    }
+    
+    return(p_critical)
   }
   
   # Uncorrelated Sidak correction
